Point3D class

A point.

Implemented types
Mixed-in types

Constructors

Point3D(Vector3 position, {double? width, Color? color, String? label})
Creates a point.

Properties

color Color?
Color of the point. Defaults to DiTreDiConfig setting.
final
hashCode int
The hash code for this object.
no setteroverride
label String?
Optional text label for the point.
final
position → Vector3
Position of the point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
Width of the point.
final

Methods

clone() Point3D
Makes a copy of this model.
override
copyWith({Vector3? position, double? width, Color? color, String? label}) Point3D
Copies the point.
getBounds() → Aabb3
Gets bounds of a model (min and max coordinates).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(InfinityModelConfig config, InfinityModelController controller, PaintViewPort viewPort, Point3D model, Matrix4 matrix, int vertexIndex, Float32List zIndices, Int32List colors, Float32List vertices) → void
Fills the buffer with the Model3D data.
inherited
toLines() List<Line3D>
Converts model to a List of Line3D.
override
toPoints() List<Point3D>
Converts model to a List of Point3D.
override
toString() String
A string representation of this object.
inherited
verticesCount() int
Returns number of vertices.
override

Operators

operator ==(Object other) bool
The equality operator.
override