LineLabel class

Label information for line segments

Constructors

LineLabel({required String text, required double position, TextStyle? style, Vector3? offset})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
offset → Vector3?
final
position → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited