supportZIndex property
If true, drawn objects will be sorted by distance to the camera. Disable to improve performance.
Implementation
final bool supportZIndex;
If true, drawn objects will be sorted by distance to the camera. Disable to improve performance.
final bool supportZIndex;