TextLabelMixin mixin

Mixin providing default implementations for text labeling

Implemented types
Mixin applications

Properties

customLabels Map<Vector3, String>?
Additional position-specific labels
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
labelStyle TextStyle?
Style for custom labels
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
Main text label
no setterinherited
textAlignment TextAlign
Text alignment
no setteroverride
textBackground bool
Whether to show text background
no setteroverride
textBackgroundColor Color
Text background color
no setteroverride
textOffset → Vector3?
Text offset
no setterinherited
textRotation bool
Whether text rotates with camera
no setteroverride
textStyle TextStyle?
Text style
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited