TextLabelSupport class abstract
Abstract class for text label support
- Implementers
Constructors
Properties
-
customLabels
→ Map<
Vector3, String> ? -
Additional position-specific labels
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelStyle → TextStyle?
-
Style for custom labels
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Main text label
no setter
- textAlignment → TextAlign
-
Text alignment
no setter
- textBackground → bool
-
Whether to show text background
no setter
- textBackgroundColor → Color
-
Text background color
no setter
- textOffset → Vector3?
-
Text offset
no setter
- textRotation → bool
-
Whether text rotates with camera
no setter
- textStyle → TextStyle?
-
Text style
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited