CanvasModelPainter class
Draws a InfinityModel data on a Canvas. Shouldn't be used directly, use InfinityModel instead.
- Inheritance
-
- Object
- Listenable
- CustomPainter
- CanvasModelPainter
- Implemented types
Constructors
-
CanvasModelPainter(List<
Model3D> _figures, Aabb3? bounds, InfinityModelController _controller, InfinityModelConfig _config) - Creates a CanvasModelPainter.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
Methods
-
addLabel(
String text, double x, double y, Color color, {double? fontSize, double rotation = 0.0}) → void -
Adds a label to be rendered on top of the scene. Coordinates are in
transformed screen space (pixels) where origin is the center of canvas.
rotationis an optional clockwise rotation in radians to rotate the text (useful for drawing labels parallel to lines).override -
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
isLineVisible(
Vector3 a, Vector3 b) → bool -
Checks if line is visible in the current viewport.
override
-
isTriangleVisible(
Triangle t) → bool -
Checks if triangle is visible in the current viewport.
override
-
isVectorVisible(
Vector3 vector) → bool -
Checks if vector is visible in the current viewport.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant CanvasModelPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited