PaintViewPort class abstract

Describes painting ViewPort (ViewPort is a rectangle in the buffer).

Implementers

Constructors

PaintViewPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLabel(String text, double x, double y, Color color, {double? fontSize, double rotation = 0.0}) → void
Adds a label to be rendered on top of the scene. Coordinates are in transformed screen space (pixels) where origin is the center of canvas. rotation is an optional clockwise rotation in radians to rotate the text (useful for drawing labels parallel to lines).
isLineVisible(Vector3 a, Vector3 b) bool
Checks if line is visible in the current viewport.
isTriangleVisible(Triangle t) bool
Checks if triangle is visible in the current viewport.
isVectorVisible(Vector3 vector) bool
Checks if vector is visible in the current viewport.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited