Line3D class
A 3D line.
- Implemented types
- Mixed-in types
Constructors
Properties
- a → Vector3
-
Start point.
final
- b → Vector3
-
End point.
final
- color → Color?
-
Color of the line. Defaults to
DiTreDiConfigsetting.final - hashCode → int
-
The hash code for this object.
no setteroverride
- label → String?
-
Optional text label for the line.
final
- labelOffset → Vector3?
-
Optional 3D offset applied to the label position (in world coordinates).
final
- labelPosition → double
-
Position along the line where the label should appear (0.0 - 1.0).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
Width of the line. Defaults to
DiTreDiConfigsetting.final
Methods
-
clone(
) → Line3D -
Makes a copy of this model.
override
-
copyWith(
{Vector3? a, Vector3? b, double? width, Color? color, String? label, double? labelPosition, Vector3? labelOffset}) → Line3D - Copies the line.
-
getBounds(
) → Aabb3 -
Gets bounds of a model (min and max coordinates).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
InfinityModelConfig config, InfinityModelController controller, PaintViewPort viewPort, Line3D model, Matrix4 matrix, int vertexIndex, Float32List zIndices, Int32List colors, Float32List vertices) → void -
Fills the buffer with the Model3D data.
inherited
-
toLines(
) → List< Line3D> -
Converts model to a List of Line3D.
override
-
toPoints(
) → List< Point3D> -
Converts model to a List of Point3D.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
verticesCount(
) → int -
Returns number of vertices.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override