TextLabelMixin mixin
Mixin that provides text labeling capabilities to 3D models
Properties
-
customLabels
→ Map<
Vector3, String> ? -
Custom labels for specific positions
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelStyle → TextStyle?
-
Style for custom labels
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Main text label for the model
no setter
- textAlignment → TextAlign
-
Text alignment
no setter
- textBackground → bool
-
Whether to show text background
no setter
- textBackgroundColor → Color
-
Color of text background
no setter
- textOffset → Vector3?
-
Offset for the text position
no setter
- textRotation → bool
-
Whether the text should rotate with the camera
no setter
- textStyle → TextStyle?
-
Style for the main text label
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited