addLabel abstract method
void
addLabel(})
Adds a label to be rendered on top of the scene. Coordinates are in
transformed screen space (pixels) where origin is the center of canvas.
rotation is an optional clockwise rotation in radians to rotate the text
(useful for drawing labels parallel to lines).
Implementation
void addLabel(
String text,
double x,
double y,
Color color, {
double? fontSize,
double rotation = 0.0,
});